@@ -11,7 +11,9 @@ args/kwargs that were used for execution, and error details if any).
 """
 
 from .basic import Action, EvalAction, ActionList
-from .configured import ConfiguredAction, ConfiguredActionList, ThreadedTrackedAction, TrackedActionList, TrackedAction
+from .configured import (ConfiguredAction, ConfiguredActionList, ThreadedTrackedAction, TrackedActionList,
+                         TrackedAction, ConfigurableInstance
+                         )
 from .logic import ConfiguredDecision, TrackedDecision
 
 __all__ = [
@@ -19,6 +21,7 @@ __all__ = [
     'EvalAction',
     'ActionList',
     'ConfiguredAction',
+    'ConfigurableInstance',
     'ConfiguredActionList',
     'ConfiguredDecision',
     'TrackedAction',
