@@ -22,6 +22,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                  *args,
                  configuration_name: str = None,
                  next_action: Union[str, 'ConfiguredAction'] = None,
+                 aliases: List[str] = None,
                  **kwargs,
                  ):
         """
@@ -40,6 +41,10 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         self._action: Action = None
         self._config_name: str = None
         self._next_action = None
+        # list of aliases for the configuration
+        if aliases is None:
+            aliases = []  # prevent mutation
+        self.aliases: List[str] = aliases
         # register action and store attribute
         self.action = action
         Configuration.__init__(
@@ -160,6 +165,19 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                 return target_name
             i += 1
 
+    def add_alias(self, alias: str):
+        """adds a configuration name alias to the instance"""
+        alias = alias.lower()  # enforces lower case
+        if alias not in self.aliases:
+            # if not already defined, add alias
+            self.aliases.append(alias)
+
+    def remove_alias(self, alias: str):
+        """removes an alias from the instance"""
+        alias = alias.lower()
+        if alias in self.aliases:
+            self.aliases.remove(alias)
+
     @staticmethod
     def _match_instance_key(inst: "ConfiguredAction", identifier: str) -> bool:
         """
@@ -175,6 +193,8 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
             return True
         elif inst.name == identifier:  # match configuration name
             return True
+        elif type(identifier) is str and identifier.lower() in inst.aliases:
+            return True  # match alias
         return False
 
     @classmethod
